@@ -24,6 +24,19 @@ def test_spacyner():
     assert republic.label == 'GPE'
 
 
+def test_scispacyner():
+    model = SpacyNERAnnotator.get_model()
+    model_class = model.construct().__class__
+    assert model_class == SpacyNERParameters
+    annotator = SpacyNERAnnotator()
+    parameters = SpacyNERParameters(model='en_core_sci_sm')
+    docs: List[Document] = annotator.annotate([Document(
+        text="Myeloid derived suppressor cells (MDSC) are immature myeloid cells with immunosuppressive activity.\nThey accumulate in tumor-bearing mice and humans with different types of cancer, including hepatocellular carcinoma (HCC).",
+        metadata=parameters.dict())], parameters)
+    doc0 = docs[0]
+    assert len(doc0.annotations) == 12
+
+
 def test_cached_nlp():
     parameters1 = SpacyNERParameters()
     nlp1 = get_nlp(parameters1.model)
